@@ -11,9 +11,19 @@
 
 #include <midori/midori.h>
 
-void
-statusbar_features_app_add_browser_cb (MidoriApp*     app,
-                                       MidoriBrowser* browser)
+static void
+statusbar_features_deactivate_cb (MidoriExtension* extension,
+                                  GtkWidget*       bbox)
+{
+    gtk_widget_destroy (bbox);
+    g_signal_handlers_disconnect_by_func (
+        extension, statusbar_features_deactivate_cb, bbox);
+}
+
+static void
+statusbar_features_app_add_browser_cb (MidoriApp*       app,
+                                       MidoriBrowser*   browser,
+                                       MidoriExtension* extension)
 {
     GtkWidget* statusbar;
     GtkWidget* bbox;
@@ -49,14 +59,25 @@ statusbar_features_app_add_browser_cb (MidoriApp*     app,
     gtk_widget_show (button);
     gtk_widget_show (bbox);
     gtk_box_pack_start (GTK_BOX (statusbar), bbox, FALSE, FALSE, 3);
+
+    g_signal_connect (extension, "deactivate",
+        G_CALLBACK (statusbar_features_deactivate_cb), bbox);
 }
 
 static void
 statusbar_features_activate_cb (MidoriExtension* extension,
                                 MidoriApp*       app)
 {
+    KatzeArray* browsers;
+    MidoriBrowser* browser;
+    guint i;
+
+    browsers = katze_object_get_object (app, "browsers");
+    i = 0;
+    while ((browser = katze_array_get_nth_item (browsers, i++)))
+        statusbar_features_app_add_browser_cb (app, browser, extension);
     g_signal_connect (app, "add-browser",
-        G_CALLBACK (statusbar_features_app_add_browser_cb), NULL);
+        G_CALLBACK (statusbar_features_app_add_browser_cb), extension);
 }
 
 MidoriExtension*
