@@ -35,7 +35,8 @@ enum
     PROP_URI,
     PROP_ICON,
     PROP_TOKEN,
-    PROP_ADDED
+    PROP_ADDED,
+    PROP_PARENT
 };
 
 static void
@@ -122,6 +123,23 @@ katze_item_class_init (KatzeItemClass* class)
                                      0,
                                      flags));
 
+    /**
+    * KatzeItem:parent:
+    *
+    * The parent of the item.
+    *
+    * Since: 0.1.2
+    */
+    g_object_class_install_property (gobject_class,
+                                     PROP_PARENT,
+                                     g_param_spec_object (
+                                     "parent",
+                                     "Parent",
+                                     "The parent of the item",
+                                     G_TYPE_OBJECT,
+                                     flags));
+
+    class->copy = NULL;
 }
 
 
@@ -174,6 +192,9 @@ katze_item_set_property (GObject*      object,
     case PROP_ADDED:
         item->added = g_value_get_int64 (value);
         break;
+    case PROP_PARENT:
+        katze_item_set_parent (item, g_value_get_object (value));
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -208,6 +229,9 @@ katze_item_get_property (GObject*    object,
     case PROP_ADDED:
         g_value_set_int64 (value, item->added);
         break;
+    case PROP_PARENT:
+        g_value_set_object (value, item->parent);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -433,6 +457,8 @@ katze_item_set_added (KatzeItem* item,
  *
  * Determines the parent of @item.
  *
+ * Since 0.1.2 you can monitor the "parent" property.
+ *
  * Return value: the parent of the item
  **/
 gpointer
@@ -450,18 +476,55 @@ katze_item_get_parent (KatzeItem* item)
  *
  * Sets the parent of @item.
  *
- * This is intended for item container implementations and
- * should not be used otherwise.
+ * This is intended for item container implementations. Notably
+ * the new parent will not be notified of the change.
+ *
+ * Since 0.1.2 you can monitor the "parent" property, so unsetting
+ * the parent is actually safe if the parent supports it.
  **/
 void
 katze_item_set_parent (KatzeItem* item,
                        gpointer   parent)
 {
     g_return_if_fail (KATZE_IS_ITEM (item));
+    g_return_if_fail (!parent || G_IS_OBJECT (parent));
 
     if (parent)
         g_object_ref (parent);
     katze_object_assign (item->parent, parent);
-    /* g_object_notify (G_OBJECT (item), "parent"); */
+    g_object_notify (G_OBJECT (item), "parent");
 }
 
+/**
+ * katze_item_copy:
+ * @item: a #KatzeItem
+ *
+ * Creates an exact copy of @item.
+ *
+ * Note that subclass specific features will only
+ * be preserved if the class implements it.
+ *
+ * Return value: a new #KatzeItem
+ *
+ * Since: 0.1.3
+ **/
+KatzeItem*
+katze_item_copy (KatzeItem* item)
+{
+    KatzeItem* copy;
+    KatzeItemClass* class;
+
+    g_return_val_if_fail (KATZE_IS_ITEM (item), NULL);
+
+    copy = g_object_new (G_OBJECT_TYPE (item),
+        "name", item->name,
+        "text", item->text,
+        "uri", item->uri,
+        "icon", item->icon,
+        "token", item->token,
+        "added", item->added,
+        "parent", item->parent,
+        NULL);
+    class = KATZE_ITEM_GET_CLASS (item);
+    return class->copy ? class->copy (copy) : copy;
+}
