@@ -15,6 +15,7 @@
 #include <glib/gi18n.h>
 /* Needed for versioning macros */
 #include <webkit/webkit.h>
+#include "compat.h"
 
 struct _GjsValue
 {
@@ -198,7 +199,7 @@ gjs_value_get_string (GjsValue* value)
     return value->string;
 }
 
-void
+static void
 gjs_value_weak_notify_cb (GjsValue* attribute,
                           GjsValue* value)
 {
@@ -542,7 +543,7 @@ _js_class_get_property_names_cb (JSContextRef                 js_context,
         guint n;
         GParamSpec** pspecs = g_object_class_list_properties (
             G_OBJECT_GET_CLASS (object), &n);
-        gint i;
+        guint i;
         for (i = 0; i < n; i++)
         {
             const gchar* property = g_param_spec_get_name (pspecs[i]);
@@ -556,8 +557,8 @@ _js_class_get_property_names_cb (JSContextRef                 js_context,
             guint* signals = g_signal_list_ids (type, &n);
             for (i = 0; i < n; i++)
             {
-                const gchar* signal = g_signal_name (signals[i]);
-                JSStringRef js_signal = JSStringCreateWithUTF8CString (signal);
+                const gchar* signal_ = g_signal_name (signals[i]);
+                JSStringRef js_signal = JSStringCreateWithUTF8CString (signal_);
                 JSPropertyNameAccumulatorAddName (js_properties, js_signal);
                 JSStringRelease (js_signal);
             }
@@ -622,7 +623,7 @@ _js_object_call_as_function_cb (JSContextRef     js_context,
     GValue* values = g_new0 (GValue, n_arguments + 1);
     g_value_init (&values[0], G_OBJECT_TYPE (object));
     g_value_set_instance (&values[0], object);
-    gint i;
+    guint i;
     for (i = 0; i < n_arguments; i++)
     {
         GValue value = {0, };
@@ -1002,7 +1003,7 @@ _js_module_get_property_cb (JSContextRef js_context,
     return result;
 }
 
-JSObjectRef
+static JSObjectRef
 gjs_module_new (JSContextRef js_context,
                 const gchar* namespace)
 {
@@ -1022,13 +1023,11 @@ gjs_module_new (JSContextRef js_context,
 JSGlobalContextRef
 gjs_global_context_new (void)
 {
-    #ifdef WEBKIT_CHECK_VERSION
     #if WEBKIT_CHECK_VERSION (1, 0, 3)
     JSGlobalContextRef js_context = JSGlobalContextCreateInGroup (NULL, NULL);
     #else
     JSGlobalContextRef js_context = JSGlobalContextCreate (NULL);
     #endif
-    #endif
     JSObjectRef js_object = gjs_object_new (js_context, "GJS", NULL);
     _js_object_set_property (js_context, JSContextGetGlobalObject (js_context),
                              "gjs", js_object);
