@@ -61,7 +61,7 @@ typedef struct
   GdkCursorType cursor_type;
   gboolean custom_cursor;
   GtkImageType storage_type;
-  #if HAVE_GIO
+  #if GLIB_CHECK_VERSION (2, 16, 0)
   GIcon *gicon;
   #endif
   gchar *icon_name;
@@ -97,9 +97,7 @@ enum
   PROP_SENSITIVITY_SECONDARY
 };
 
-static void gtk_icon_entry_class_init        (GtkIconEntryClass    *klass);
 static void gtk_icon_entry_editable_init     (GtkEditableClass     *iface);
-static void gtk_icon_entry_init              (GtkIconEntry         *entry);
 static void gtk_icon_entry_finalize          (GObject              *obj);
 static void gtk_icon_entry_dispose           (GObject              *obj);
 static void gtk_icon_entry_map               (GtkWidget            *widget);
@@ -185,8 +183,9 @@ gtk_icon_entry_class_init (GtkIconEntryClass *klass)
    *
    * The ::icon-pressed signal is emitted when an icon is clicked.
    */
+  if (!(signals[ICON_PRESSED] = g_signal_lookup ("icon-pressed", GTK_TYPE_ENTRY)))
   signals[ICON_PRESSED] =
-    g_signal_new ("icon_pressed",
+    g_signal_new ("icon-pressed",
 		  G_TYPE_FROM_CLASS (gobject_class),
 		  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		  G_STRUCT_OFFSET (GtkIconEntryClass, icon_pressed),
@@ -205,8 +204,9 @@ gtk_icon_entry_class_init (GtkIconEntryClass *klass)
    * The ::icon-released signal is emitted on the button release from a
    * mouse click.
    */
+  if (!(signals[ICON_RELEASED] = g_signal_lookup ("icon-released", GTK_TYPE_ENTRY)))
   signals[ICON_RELEASED] =
-    g_signal_new ("icon_released",
+    g_signal_new ("icon-released",
 		  G_TYPE_FROM_CLASS (gobject_class),
 		  G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		  G_STRUCT_OFFSET (GtkIconEntryClass, icon_released),
@@ -274,7 +274,7 @@ gtk_icon_entry_class_init (GtkIconEntryClass *klass)
 							NULL,
 							GTK_PARAM_WRITABLE));
 
-  #if HAVE_GIO
+  #if GLIB_CHECK_VERSION (2, 16, 0)
   g_object_class_install_property (gobject_class,
 				   PROP_GICON_PRIMARY,
 				   g_param_spec_object ("gicon-primary",
@@ -433,7 +433,7 @@ gtk_icon_entry_set_property (GObject      *object,
 					      g_value_get_string (value));
       break;
 
-    #if HAVE_GIO
+    #if GLIB_CHECK_VERSION (2, 16, 0)
     case PROP_GICON_PRIMARY:
       gtk_icon_entry_set_icon_from_gicon (entry,
 					  GTK_ICON_ENTRY_PRIMARY,
@@ -471,7 +471,7 @@ gtk_icon_entry_get_property (GObject      *object,
 						     GTK_ICON_ENTRY_SECONDARY));
       break;
 
-    #if HAVE_GIO
+    #if GLIB_CHECK_VERSION (2, 16, 0)
     case PROP_GICON_PRIMARY:
       g_value_set_object (value,
 			  gtk_icon_entry_get_gicon (entry,
@@ -1104,7 +1104,7 @@ icon_theme_changed (GtkIconEntry *entry)
 	  gtk_icon_entry_set_icon_from_icon_name (entry, i, priv->icons[i].icon_name);
 	}
 
-      #if HAVE_GIO
+      #if GLIB_CHECK_VERSION (2, 16, 0)
       else if (priv->icons[i].storage_type == _GTK_IMAGE_GICON)
 	{
 	  g_object_unref (priv->icons[i].pixbuf);
@@ -1339,7 +1339,7 @@ gtk_icon_entry_set_icon_from_icon_name (GtkIconEntry *entry,
  * appropriately.
  */
 
-#if HAVE_GIO
+#if GLIB_CHECK_VERSION (2, 16, 0)
 void
 gtk_icon_entry_set_icon_from_gicon (const GtkIconEntry *entry,
 				    GtkIconEntryPosition icon_pos,
@@ -1493,7 +1493,7 @@ gtk_icon_entry_get_pixbuf (const GtkIconEntry *entry,
  */
 
 
-#if HAVE_GIO
+#if GLIB_CHECK_VERSION (2, 16, 0)
 GIcon *
 gtk_icon_entry_get_gicon (const GtkIconEntry *entry,
 			  GtkIconEntryPosition icon_pos)
