@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007-2008 Christian Dywan <christian@twotoasts.de>
+ Copyright (C) 2007-2009 Christian Dywan <christian@twotoasts.de>
  Copyright (C) 2008 Dale Whittaker <dayul@users.sf.net>
 
  This library is free software; you can redistribute it and/or
@@ -25,10 +25,12 @@
 #include "midori-panel.h"
 #include "midori-preferences.h"
 #include "midori-plugins.h"
+#include "midori-transfers.h"
 #include "midori-view.h"
 #include "midori-websettings.h"
 
 #include "sokoke.h"
+#include "compat.h"
 
 #if HAVE_UNISTD_H
     #include <unistd.h>
@@ -41,8 +43,7 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
-#include <JavaScriptCore/JavaScript.h>
+#include <webkit/webkit.h>
 
 #if HAVE_LIBXML
     #include <libxml/parser.h>
@@ -53,10 +54,6 @@
     #include <sqlite3.h>
 #endif
 
-#if HAVE_LIBSOUP
-    #include <libsoup/soup.h>
-#endif
-
 #if ENABLE_NLS
     #include <libintl.h>
     #include <locale.h>
@@ -761,7 +758,7 @@ midori_history_add_items (void*  data,
                     katze_item_set_added (KATZE_ITEM (parent), day);
                     strftime (token, sizeof (token), "%x",
                           localtime ((time_t *)&date));
-                    katze_item_set_token (KATZE_ITEM (parent), token);
+                    katze_item_set_name (KATZE_ITEM (parent), token);
                     katze_array_add_item (array, parent);
                 }
                 katze_array_add_item (parent, item);
@@ -1217,11 +1214,10 @@ midori_app_add_browser_cb (MidoriApp*     app,
     midori_panel_append_page (MIDORI_PANEL (panel), MIDORI_VIEWABLE (addon));
 
     /* Transfers */
-    #if 0
-    addon = midori_view_new (net);
+    #if WEBKIT_CHECK_VERSION (1, 1, 3)
+    addon = g_object_new (MIDORI_TYPE_TRANSFERS, "app", app, NULL);
     gtk_widget_show (addon);
-    midori_panel_append_widget (MIDORI_PANEL (panel), addon,
-                                STOCK_TRANSFERS, _("Transfers"), NULL);
+    midori_panel_append_page (MIDORI_PANEL (panel), MIDORI_VIEWABLE (addon));
     #endif
 
     /* Console */
@@ -1276,9 +1272,6 @@ midori_browser_weak_notify_cb (MidoriBrowser* browser,
                          G_CALLBACK (midori_browser_session_cb), session, NULL);
 }
 
-#if HAVE_LIBSOUP
-typedef void (*GObjectConstructed) (GObject*);
-
 static void
 soup_session_settings_notify_http_proxy_cb (MidoriWebSettings* settings,
                                             GParamSpec*        pspec,
@@ -1325,34 +1318,21 @@ midori_soup_session_debug (SoupSession* session)
     }
 }
 
-/* The following code hooks up to any created soup session in order to
-   modify preferences. This is *not* a generally advisable technique
-   but merely a preliminary workaround until WebKit exposes its session. */
-static GObjectConstructed old_session_constructed_cb;
 static void
-soup_session_constructed_cb (GObject* object)
+midori_soup_session_prepare (SoupSession*       session,
+                             MidoriWebSettings* settings)
 {
-    MidoriApp* app;
-    MidoriWebSettings* settings;
-    SoupSession* session;
     SoupSessionFeature* feature;
     gchar* config_file;
 
-    if (old_session_constructed_cb)
-        old_session_constructed_cb (object);
-    app = g_type_get_qdata (SOUP_TYPE_SESSION,
-        g_quark_from_static_string ("midori-app"));
-    settings = katze_object_get_object (app, "settings");
-    session = SOUP_SESSION (object);
-
     soup_session_settings_notify_http_proxy_cb (settings, NULL, session);
     soup_session_settings_notify_ident_string_cb (settings, NULL, session);
     g_signal_connect (settings, "notify::http-proxy",
-        G_CALLBACK (soup_session_settings_notify_http_proxy_cb), object);
+        G_CALLBACK (soup_session_settings_notify_http_proxy_cb), session);
     g_signal_connect (settings, "notify::auto-detect-proxy",
-        G_CALLBACK (soup_session_settings_notify_http_proxy_cb), object);
+        G_CALLBACK (soup_session_settings_notify_http_proxy_cb), session);
     g_signal_connect (settings, "notify::ident-string",
-        G_CALLBACK (soup_session_settings_notify_ident_string_cb), object);
+        G_CALLBACK (soup_session_settings_notify_ident_string_cb), session);
 
     soup_session_add_feature_by_type (session, KATZE_TYPE_HTTP_AUTH);
     midori_soup_session_debug (session);
@@ -1363,7 +1343,6 @@ soup_session_constructed_cb (GObject* object)
                             config_file, (GDestroyNotify)g_free);
     soup_session_add_feature (session, feature);
 }
-#endif
 
 static void
 button_modify_preferences_clicked_cb (GtkWidget*         button,
@@ -1491,7 +1470,12 @@ midori_load_extensions (gpointer data)
 
                 if (module && g_module_symbol (module, "extension_init",
                                                (gpointer) &extension_init))
+                {
                     extension = extension_init ();
+                    /* FIXME: Validate the extension */
+                    /* Signal that we want the extension to load and save */
+                    midori_extension_get_config_dir (extension);
+                }
                 else
                 {
                     extension = g_object_new (MIDORI_TYPE_EXTENSION,
@@ -1602,16 +1586,7 @@ midori_run_script (const gchar* filename)
     gchar* script;
     GError* error = NULL;
 
-    #ifdef WEBKIT_CHECK_VERSION
-    #if WEBKIT_CHECK_VERSION (1, 0, 3)
-    #define HAVE_JSCONTEXTGROUP 1
-    #endif
-    #endif
-    #if HAVE_JSCONTEXTGROUP
     js_context = JSGlobalContextCreateInGroup (NULL, NULL);
-    #else
-    js_context = JSGlobalContextCreate (NULL);
-    #endif
 
     if (g_file_get_contents (filename, &script, NULL, &error))
     {
@@ -1668,14 +1643,9 @@ main (int    argc,
     gchar* uri;
     KatzeItem* item;
     gchar* uri_ready;
-    #if HAVE_LIBSOUP
-    GObjectClass* webkit_class;
     KatzeNet* net;
     SoupSession* s_session;
-    #endif
-    #if HAVE_LIBSOUP_2_25_2
     SoupCookieJar* jar;
-    #endif
     #if HAVE_SQLITE
     sqlite3* db;
     gint max_history_age;
@@ -1756,24 +1726,6 @@ main (int    argc,
         return 1;
     }
 
-    #if HAVE_LIBSOUP
-    webkit_class = g_type_class_ref (WEBKIT_TYPE_WEB_VIEW);
-    if (!g_object_class_find_property (webkit_class, "session"))
-    {
-    /* This is a nasty trick that allows us to manipulate preferences
-       even without having a pointer to the session. */
-    soup_session_get_type ();
-    SoupSessionClass* session_class = g_type_class_ref (SOUP_TYPE_SESSION);
-    if (session_class)
-    {
-        g_type_set_qdata (SOUP_TYPE_SESSION,
-                          g_quark_from_static_string ("midori-app"), app);
-        old_session_constructed_cb = G_OBJECT_CLASS (session_class)->constructed;
-        G_OBJECT_CLASS (session_class)->constructed = soup_session_constructed_cb;
-    }
-    }
-    #endif
-
     /* Load configuration files */
     error_messages = g_string_new (NULL);
     config_file = build_config_filename ("config");
@@ -1917,30 +1869,23 @@ main (int    argc,
     }
     g_string_free (error_messages, TRUE);
 
-    #if HAVE_LIBSOUP
-    webkit_class = g_type_class_ref (WEBKIT_TYPE_WEB_VIEW);
-    if (g_object_class_find_property (webkit_class, "session"))
+    if (1)
     {
+        SoupSession* webkit_session = webkit_get_default_session ();
+
         net = katze_net_new ();
         s_session = katze_net_get_session (net);
-        #if HAVE_LIBSOUP_2_25_2
+        g_type_set_qdata (SOUP_TYPE_SESSION,
+                          g_quark_from_static_string ("midori-app"), app);
         katze_assign (config_file, build_config_filename ("cookies.txt"));
-        jar = soup_cookie_jar_text_new (config_file, FALSE);
-        /* FIXME: Handle "accept-cookies" preference */
+        jar = soup_cookie_jar_new ();
         soup_session_add_feature (s_session, SOUP_SESSION_FEATURE (jar));
+        soup_session_add_feature (webkit_session, SOUP_SESSION_FEATURE (jar));
         g_object_unref (jar);
-        #endif
-        soup_session_settings_notify_http_proxy_cb (settings, NULL, s_session);
-        soup_session_settings_notify_ident_string_cb (settings, NULL, s_session);
-        g_signal_connect (settings, "notify::http-proxy",
-            G_CALLBACK (soup_session_settings_notify_http_proxy_cb), s_session);
-        g_signal_connect (settings, "notify::ident-string",
-            G_CALLBACK (soup_session_settings_notify_ident_string_cb), s_session);
-        soup_session_add_feature_by_type (s_session, KATZE_TYPE_HTTP_AUTH);
-        midori_soup_session_debug (s_session);
+        midori_soup_session_prepare (s_session, settings);
+        midori_soup_session_prepare (webkit_session, settings);
         g_object_unref (net);
     }
-    #endif
 
     /* Open as many tabs as we have uris, seperated by pipes */
     i = 0;
