@@ -24,12 +24,15 @@ struct _MidoriPanel
     GtkHBox parent_instance;
 
     GtkWidget* toolbar;
+    GtkToolItem* button_align;
     GtkWidget* toolbar_label;
     GtkWidget* frame;
     GtkWidget* toolbook;
     GtkWidget* notebook;
     GSList*    group;
     GtkMenu*   menu;
+
+    gboolean right_aligned;
 };
 
 struct _MidoriPanelClass
@@ -49,7 +52,8 @@ enum
 
     PROP_SHADOW_TYPE,
     PROP_MENU,
-    PROP_PAGE
+    PROP_PAGE,
+    PROP_RIGHT_ALIGNED,
 };
 
 enum {
@@ -118,7 +122,7 @@ midori_panel_class_init (MidoriPanelClass* class)
 
     class->close = midori_panel_close;
 
-    flags = G_PARAM_READWRITE | G_PARAM_CONSTRUCT;
+    flags = G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS;
 
     g_object_class_install_property (gobject_class,
                                      PROP_SHADOW_TYPE,
@@ -137,7 +141,7 @@ midori_panel_class_init (MidoriPanelClass* class)
                                      "Menu",
                                      "Menu to hold panel items",
                                      GTK_TYPE_MENU,
-                                     G_PARAM_READWRITE));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_PAGE,
@@ -147,6 +151,22 @@ midori_panel_class_init (MidoriPanelClass* class)
                                      "The index of the current page",
                                      -1, G_MAXINT, -1,
                                      flags));
+
+    /**
+    * MidoriWebSettings:right-aligned:
+    *
+    * Whether to align the panel on the right.
+    *
+    * Since: 0.1.3
+    */
+    g_object_class_install_property (gobject_class,
+                                     PROP_RIGHT_ALIGNED,
+                                     g_param_spec_boolean (
+                                     "right-aligned",
+                                     "Right aligned",
+                                     "Whether the panel is aligned to the right",
+                                     FALSE,
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -157,6 +177,21 @@ midori_panel_button_close_clicked_cb (GtkWidget*   toolitem,
     g_signal_emit (panel, signals[CLOSE], 0, &return_value);
 }
 
+static void
+midori_panel_button_align_clicked_cb (GtkWidget*   toolitem,
+                                      MidoriPanel* panel)
+{
+    midori_panel_set_right_aligned (panel, !panel->right_aligned);
+}
+
+static void
+midori_panel_destroy_cb (MidoriPanel* panel)
+{
+    /* Destroy pages first, so they don't need special care */
+    gtk_container_foreach (GTK_CONTAINER (panel->notebook),
+                           (GtkCallback) gtk_widget_destroy, NULL);
+}
+
 static void
 midori_panel_init (MidoriPanel* panel)
 {
@@ -164,6 +199,8 @@ midori_panel_init (MidoriPanel* panel)
     GtkWidget* labelbar;
     GtkToolItem* toolitem;
 
+    panel->right_aligned = FALSE;
+
     /* Create the sidebar */
     panel->toolbar = gtk_toolbar_new ();
     gtk_toolbar_set_style (GTK_TOOLBAR (panel->toolbar), GTK_TOOLBAR_BOTH);
@@ -187,6 +224,19 @@ midori_panel_init (MidoriPanel* panel)
     gtk_container_add (GTK_CONTAINER (toolitem), panel->toolbar_label);
     gtk_container_set_border_width (GTK_CONTAINER (toolitem), 6);
     gtk_toolbar_insert (GTK_TOOLBAR (labelbar), toolitem, -1);
+    toolitem = gtk_tool_button_new_from_stock (GTK_STOCK_GO_FORWARD);
+    gtk_tool_button_set_label (GTK_TOOL_BUTTON (toolitem),
+                               _("Align sidepanel on the right"));
+    gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM (toolitem),
+                               _("Whether to align the sidepanel on the right"));
+    g_signal_connect (toolitem, "clicked",
+        G_CALLBACK (midori_panel_button_align_clicked_cb), panel);
+    #if HAVE_OSX
+    gtk_toolbar_insert (GTK_TOOLBAR (labelbar), toolitem, 0);
+    #else
+    gtk_toolbar_insert (GTK_TOOLBAR (labelbar), toolitem, -1);
+    #endif
+    panel->button_align = toolitem;
     toolitem = gtk_tool_button_new_from_stock (GTK_STOCK_CLOSE);
     gtk_tool_button_set_label (GTK_TOOL_BUTTON (toolitem), _("Close panel"));
     gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM (toolitem), _("Close panel"));
@@ -215,18 +265,14 @@ midori_panel_init (MidoriPanel* panel)
     gtk_container_add (GTK_CONTAINER (panel->frame), panel->notebook);
     gtk_box_pack_start (GTK_BOX (vbox), panel->frame, TRUE, TRUE, 0);
     gtk_widget_show_all (panel->frame);
+
+    g_signal_connect (panel, "destroy",
+                      G_CALLBACK (midori_panel_destroy_cb), NULL);
 }
 
 static void
 midori_panel_finalize (GObject* object)
 {
-    MidoriPanel* panel = MIDORI_PANEL (object);
-
-    if (panel->menu)
-    {
-        /* FIXME: Remove all menu items */
-    }
-
     G_OBJECT_CLASS (midori_panel_parent_class)->finalize (object);
 }
 
@@ -251,6 +297,9 @@ midori_panel_set_property (GObject*      object,
     case PROP_PAGE:
         midori_panel_set_current_page (panel, g_value_get_int (value));
         break;
+    case PROP_RIGHT_ALIGNED:
+        midori_panel_set_right_aligned (panel, g_value_get_boolean (value));
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -277,6 +326,9 @@ midori_panel_get_property (GObject*    object,
     case PROP_PAGE:
         g_value_set_int (value, midori_panel_get_current_page (panel));
         break;
+    case PROP_RIGHT_ALIGNED:
+        g_value_set_boolean (value, panel->right_aligned);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -311,10 +363,38 @@ midori_panel_set_compact (MidoriPanel* panel,
 {
     g_return_if_fail (MIDORI_IS_PANEL (panel));
 
+    #if HAVE_HILDON
+    compact = TRUE;
+    #endif
     gtk_toolbar_set_style (GTK_TOOLBAR (panel->toolbar),
         compact ? GTK_TOOLBAR_ICONS : GTK_TOOLBAR_BOTH);
 }
 
+/**
+ * midori_panel_set_right_aligned:
+ * @compact: %TRUE if the panel should be aligned to the right
+ *
+ * Determines if the panel should be right aligned.
+ *
+ * Since: 0.1.3
+ **/
+void
+midori_panel_set_right_aligned (MidoriPanel* panel,
+                                gboolean     right_aligned)
+{
+    GtkWidget* box;
+
+    g_return_if_fail (MIDORI_IS_PANEL (panel));
+
+    box = gtk_widget_get_parent (panel->toolbar);
+    gtk_box_reorder_child (GTK_BOX (box), panel->toolbar,
+        right_aligned ? -1 : 0);
+    gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (panel->button_align),
+        right_aligned ? GTK_STOCK_GO_BACK : GTK_STOCK_GO_FORWARD);
+    panel->right_aligned = right_aligned;
+    g_object_notify (G_OBJECT (panel), "right-aligned");
+}
+
 static void
 midori_panel_menu_item_activate_cb (GtkWidget*   widget,
                                     MidoriPanel* panel)
@@ -342,6 +422,26 @@ midori_panel_menu_item_activate_cb (GtkWidget*   widget,
     }
 }
 
+static void
+midori_panel_viewable_destroy_cb (GtkWidget*   viewable,
+                                  MidoriPanel* panel)
+{
+    gint i = gtk_notebook_page_num (GTK_NOTEBOOK (panel->notebook), viewable);
+    if (i > -1)
+    gtk_notebook_remove_page (GTK_NOTEBOOK (panel->notebook), i);
+    g_signal_handlers_disconnect_by_func (
+        viewable, midori_panel_viewable_destroy_cb, panel);
+}
+
+static void
+midori_panel_widget_destroy_cb (GtkWidget* viewable,
+                                GtkWidget* widget)
+{
+    gtk_widget_destroy (widget);
+    g_signal_handlers_disconnect_by_func (
+        viewable, midori_panel_widget_destroy_cb, widget);
+}
+
 /**
  * midori_panel_append_page:
  * @panel: a #MidoriPanel
@@ -353,6 +453,9 @@ midori_panel_menu_item_activate_cb (GtkWidget*   widget,
  * Appends a new page to the panel. If @toolbar is specified it will
  * be packed above @viewable.
  *
+ * Since 0.1.3 destroying the @viewable implicitly removes
+ * the page including the menu and eventual toolbar.
+ *
  * In the case of an error, -1 is returned.
  *
  * Return value: the index of the new page, or -1
@@ -401,6 +504,8 @@ midori_panel_append_page (MidoriPanel*    panel,
     toolbar = midori_viewable_get_toolbar (viewable);
     gtk_widget_show (toolbar);
     gtk_container_add (GTK_CONTAINER (panel->toolbook), toolbar);
+    g_signal_connect (viewable, "destroy",
+                      G_CALLBACK (midori_panel_widget_destroy_cb), toolbar);
 
     n = midori_panel_page_num (panel, scrolled);
     label = midori_viewable_get_label (viewable);
@@ -421,6 +526,8 @@ midori_panel_append_page (MidoriPanel*    panel,
                       G_CALLBACK (midori_panel_menu_item_activate_cb), panel);
     gtk_widget_show_all (GTK_WIDGET (toolitem));
     gtk_toolbar_insert (GTK_TOOLBAR (panel->toolbar), toolitem, -1);
+    g_signal_connect (viewable, "destroy",
+                      G_CALLBACK (midori_panel_widget_destroy_cb), toolitem);
 
     if (panel->menu)
     {
@@ -432,8 +539,13 @@ midori_panel_append_page (MidoriPanel*    panel,
                           G_CALLBACK (midori_panel_menu_item_activate_cb),
                           panel);
         gtk_menu_shell_append (GTK_MENU_SHELL (panel->menu), menuitem);
+        g_signal_connect (viewable, "destroy",
+                          G_CALLBACK (midori_panel_widget_destroy_cb), menuitem);
     }
 
+    g_signal_connect (viewable, "destroy",
+                      G_CALLBACK (midori_panel_viewable_destroy_cb), panel);
+
     return n;
 }
 
@@ -667,10 +779,10 @@ midori_dummy_viewable_finalize (GObject* object)
     G_OBJECT_CLASS (midori_dummy_viewable_parent_class)->finalize (object);
 }
 
-static GtkWidget*
+/* static */ GtkWidget*
 midori_dummy_viewable_new (const gchar* stock_id,
-                       const gchar* label,
-                       GtkWidget*   toolbar)
+                           const gchar* label,
+                           GtkWidget*   toolbar)
 {
     GtkWidget* viewable = g_object_new (MIDORI_TYPE_DUMMY_VIEWABLE, NULL);
 
@@ -695,6 +807,9 @@ midori_dummy_viewable_new (const gchar* stock_id,
  * Actually implementing #MidoriViewable instead of using
  * this convenience is recommended.
  *
+ * Since 0.1.3 destroying the @widget implicitly removes
+ * the page including the menu and eventual toolbar.
+ *
  * In the case of an error, -1 is returned.
  *
  * Return value: the index of the new page, or -1
@@ -717,5 +832,7 @@ midori_panel_append_widget (MidoriPanel* panel,
     viewable = midori_dummy_viewable_new (stock_id, label, toolbar);
     gtk_widget_show (viewable);
     gtk_container_add (GTK_CONTAINER (viewable), widget);
+    g_signal_connect (widget, "destroy",
+                      G_CALLBACK (midori_panel_widget_destroy_cb), viewable);
     return midori_panel_append_page (panel, MIDORI_VIEWABLE (viewable));
 }
