@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007-2008 Christian Dywan <christian@twotoasts.de>
+ Copyright (C) 2007-2009 Christian Dywan <christian@twotoasts.de>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -16,13 +16,11 @@
 #endif
 
 #include "sokoke.h"
+#include "compat.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
-
-#if HAVE_LIBSOUP
-    #include <libsoup/soup.h>
-#endif
+#include <libsoup/soup.h>
 
 struct _MidoriPreferences
 {
@@ -181,6 +179,21 @@ midori_preferences_new (GtkWindow*         parent,
     return GTK_WIDGET (preferences);
 }
 
+static void
+midori_preferences_homepage_current_clicked_cb (GtkWidget*         button,
+                                                MidoriWebSettings* settings)
+{
+    GtkWidget* preferences = gtk_widget_get_toplevel (button);
+    GtkWidget* browser = katze_object_get_object (preferences, "transient-for");
+
+    if (GTK_IS_WINDOW (browser))
+    {
+        gchar* uri = katze_object_get_string (browser, "uri");
+        g_object_set (settings, "homepage", uri, NULL);
+        g_free (uri);
+    }
+}
+
 static gboolean
 proxy_download_manager_icon_cb (GtkWidget*     entry,
                                 GdkEventFocus* event,
@@ -228,7 +241,6 @@ midori_preferences_notify_preferred_encoding_cb (MidoriWebSettings* settings,
     gtk_widget_set_sensitive (entry, preferred_encoding == MIDORI_ENCODING_CUSTOM);
 }
 
-#if HAVE_LIBSOUP
 static void
 midori_preferences_notify_auto_detect_proxy_cb (MidoriWebSettings* settings,
                                                 GParamSpec*        pspec,
@@ -249,7 +261,6 @@ midori_preferences_notify_identify_as_cb (MidoriWebSettings* settings,
 
     gtk_widget_set_sensitive (entry, identify_as == MIDORI_IDENT_CUSTOM);
 }
-#endif
 
 #if HAVE_OSX
 static void
@@ -316,9 +327,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     GtkWidget* entry;
     GtkWidget* hbox;
     gint icon_width, icon_height;
-    #if HAVE_LIBSOUP
-    GObjectClass* webkit_class;
-    #endif
 
     g_return_if_fail (MIDORI_IS_PREFERENCES (preferences));
     g_return_if_fail (MIDORI_IS_WEB_SETTINGS (settings));
@@ -396,17 +404,30 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     FILLED_ADD (button, 1, 2, 0, 1);
     label = katze_property_label (settings, "homepage");
     INDENTED_ADD (label, 0, 1, 1, 2);
-    /* TODO: We need something like "use current website" */
+    hbox = gtk_hbox_new (FALSE, 4);
     entry = katze_property_proxy (settings, "homepage", NULL);
-    FILLED_ADD (entry, 1, 2, 1, 2);
+    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+    if (parent && katze_object_has_property (parent, "uri"))
+    {
+        button = gtk_button_new ();
+        label = gtk_image_new_from_stock (GTK_STOCK_JUMP_TO, GTK_ICON_SIZE_BUTTON);
+        gtk_button_set_image (GTK_BUTTON (button), label);
+        gtk_widget_set_tooltip_text (button, _("Use current page as homepage"));
+        g_signal_connect (button, "clicked",
+            G_CALLBACK (midori_preferences_homepage_current_clicked_cb), settings);
+        gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+    }
+    FILLED_ADD (hbox, 1, 2, 1, 2);
     button = katze_property_proxy (settings, "show-crash-dialog", "blurb");
     SPANNED_ADD (button, 0, 2, 2, 3);
     FRAME_NEW (_("Transfers"));
     TABLE_NEW (3, 2);
+    #if WEBKIT_CHECK_VERSION (1, 1, 3)
     label = katze_property_label (settings, "download-folder");
     INDENTED_ADD (label, 0, 1, 0, 1);
     button = katze_property_proxy (settings, "download-folder", "folder");
     FILLED_ADD (button, 1, 2, 0, 1);
+    #else
     label = katze_property_label (settings, "download-manager");
     INDENTED_ADD (label, 0, 1, 1, 2);
     hbox = gtk_hbox_new (FALSE, 4);
@@ -421,6 +442,7 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     g_signal_connect (entry, "focus-out-event",
         G_CALLBACK (proxy_download_manager_icon_cb), button);
     FILLED_ADD (hbox, 1, 2, 1, 2);
+    #endif
     label = katze_property_label (settings, "text-editor");
     INDENTED_ADD (label, 0, 1, 2, 3);
     hbox = gtk_hbox_new (FALSE, 4);
@@ -554,13 +576,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     WIDGET_ADD (button, 1, 2, 5, 6);
 
     /* Page "Network" */
-    #if HAVE_LIBSOUP
-    webkit_class = g_type_class_ref (WEBKIT_TYPE_WEB_VIEW);
-    if (g_object_class_find_property (webkit_class, "session") ||
-    /* If a cookie jar was created, WebKit is using Soup */
-        g_type_get_qdata (SOUP_TYPE_COOKIE_JAR,
-        g_quark_from_static_string ("midori-has-jar")))
-    {
     PAGE_NEW (GTK_STOCK_NETWORK, _("Network"));
     FRAME_NEW (_("Network"));
     TABLE_NEW (5, 2);
@@ -592,17 +607,9 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("MB")),
                         FALSE, FALSE, 0);
     FILLED_ADD (hbox, 1, 2, 4, 5);
-    }
-    #endif
 
     /* Page "Privacy" */
     PAGE_NEW (GTK_STOCK_INDEX, _("Privacy"));
-    #if HAVE_LIBSOUP_2_25_2
-    if (g_object_class_find_property (webkit_class, "session") ||
-    /* If a cookie jar was created, WebKit is using Soup */
-        g_type_get_qdata (SOUP_TYPE_COOKIE_JAR,
-        g_quark_from_static_string ("midori-has-jar")))
-    {
     FRAME_NEW (_("Web Cookies"));
     TABLE_NEW (3, 2);
     label = katze_property_label (settings, "accept-cookies");
@@ -619,8 +626,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("days")),
                         FALSE, FALSE, 0);
     FILLED_ADD (hbox, 1, 2, 2, 3);
-    }
-    #endif
     FRAME_NEW (_("History"));
     TABLE_NEW (3, 2);
     button = katze_property_proxy (settings, "remember-last-visited-pages", NULL);
