@@ -22,20 +22,15 @@
 #define STOCK_BOOKMARK           "stock_bookmark"
 #define STOCK_BOOKMARKS          "vcard"
 #define STOCK_CONSOLE            "terminal"
-#define STOCK_DISABLE            "list-remove"
-#define STOCK_ENABLE             "list-add"
 #define STOCK_EXTENSION          "extension"
 #define STOCK_EXTENSIONS         "extension"
 #define STOCK_HISTORY            "document-open-recent"
 #define STOCK_NEWS_FEED          "news-feed"
-#define STOCK_PAGE_HOLDER        "page-holder"
 #define STOCK_STYLE              "gnome-settings-theme"
 #define STOCK_STYLES             "gnome-settings-theme"
 #define STOCK_TRANSFER           "package"
 #define STOCK_TRANSFERS          "package"
 
-/* We assume that these legacy icon names are usually present */
-
 #define STOCK_BOOKMARK_ADD       "stock_add-bookmark"
 #define STOCK_HOMEPAGE           GTK_STOCK_HOME
 #define STOCK_IMAGE              "gnome-mime-image"
@@ -47,14 +42,4 @@
 #define STOCK_USER_TRASH         "gnome-stock-trash"
 #define STOCK_WINDOW_NEW         "stock_new-window"
 
-/* For backwards compatibility */
-
-#if !GTK_CHECK_VERSION(2, 10, 0)
-#define GTK_STOCK_SELECT_ALL     "gtk-select-all"
-#endif
-#if !GTK_CHECK_VERSION(2, 8, 0)
-#define GTK_STOCK_FULLSCREEN "gtk-fullscreen"
-#define GTK_STOCK_LEAVE_FULLSCREEN "gtk-leave-fullscreen"
-#endif
-
 #endif /* !__MIDORI_STOCK_H__ */
