@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007-2008 Christian Dywan <christian@twotoasts.de>
+ Copyright (C) 2007-2009 Christian Dywan <christian@twotoasts.de>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,6 @@
 #endif
 
 #include "midori-view.h"
-#include "midori-source.h"
 #include "midori-stock.h"
 
 #include "compat.h"
@@ -34,10 +33,6 @@
     #define D_(__domain, __message) __message
 #endif
 
-#ifndef WEBKIT_CHECK_VERSION
-    #define WEBKIT_CHECK_VERSION(a,b,c) 0
-#endif
-
 /* This is unstable API, so we need to declare it */
 gchar*
 webkit_web_view_get_selected_text (WebKitWebView* web_view);
@@ -148,6 +143,7 @@ enum {
     NEW_TAB,
     NEW_WINDOW,
     NEW_VIEW,
+    DOWNLOAD_REQUESTED,
     SEARCH_TEXT,
     ADD_BOOKMARK,
     SAVE_AS,
@@ -276,6 +272,36 @@ midori_view_class_init (MidoriViewClass* class)
         MIDORI_TYPE_VIEW,
         MIDORI_TYPE_NEW_VIEW);
 
+    /**
+     * MidoriView::download-requested:
+     * @view: the object on which the signal is emitted
+     * @download: a new download
+     *
+     * Emitted when a new download is requested, if a
+     * file cannot be displayed or a download was started
+     * from the context menu.
+     *
+     * If the download should be accepted, a callback
+     * has to return %TRUE, and the download will also
+     * be started automatically.
+     *
+     * Note: This requires WebKitGTK 1.1.3.
+     *
+     * Return value: %TRUE if the download was handled
+     *
+     * Since: 0.1.5
+     */
+    signals[DOWNLOAD_REQUESTED] = g_signal_new (
+        "download-requested",
+        G_TYPE_FROM_CLASS (class),
+        (GSignalFlags)(G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION),
+        0,
+        g_signal_accumulator_true_handled,
+        NULL,
+        midori_cclosure_marshal_BOOLEAN__OBJECT,
+        G_TYPE_BOOLEAN, 1,
+        G_TYPE_OBJECT);
+
     /**
      * MidoriView::search-text:
      * @view: the object on which the signal is emitted
@@ -776,7 +802,7 @@ gtk_widget_button_press_event_cb (WebKitWebView*  web_view,
                 gtk_widget_get_display (GTK_WIDGET (view)),
                 GDK_SELECTION_PRIMARY);
             uri = gtk_clipboard_wait_for_text (clipboard);
-            if (uri && strchr (uri, '.') && !strchr (uri, ' '))
+            if (uri && strchr (uri, '.') && !strchr (g_strstrip (uri), ' '))
             {
                 new_uri = sokoke_magic_uri (uri, NULL);
                 if (event->state & GDK_CONTROL_MASK)
@@ -891,6 +917,7 @@ midori_web_view_menu_search_web_activate_cb (GtkWidget*  widget,
     g_free (uri);
 }
 
+#if !WEBKIT_CHECK_VERSION (1, 1, 3)
 static void
 midori_web_view_menu_save_as_activate_cb (GtkWidget*  widget,
                                           MidoriView* view)
@@ -904,6 +931,7 @@ midori_web_view_menu_download_activate_cb (GtkWidget*  widget,
 {
     sokoke_spawn_program (view->download_manager, view->link_uri);
 }
+#endif
 
 static void
 midori_web_view_menu_add_bookmark_activate_cb (GtkWidget*  widget,
@@ -982,6 +1010,11 @@ webkit_web_view_populate_popup_cb (WebKitWebView* web_view,
             G_CALLBACK (midori_web_view_menu_new_window_activate_cb), view);
         menuitem = (GtkWidget*)g_list_nth_data (items, 3);
         g_list_free (items);
+        #if WEBKIT_CHECK_VERSION (1, 1, 3)
+        /* hack to localize menu item */
+        label = gtk_bin_get_child (GTK_BIN (menuitem));
+        gtk_label_set_label (GTK_LABEL (label), _("_Download Link destination"));
+        #else
         /* hack to disable non-functional Download File
            FIXME: Make sure this really is the right menu item */
         gtk_widget_hide (menuitem);
@@ -1003,6 +1036,7 @@ webkit_web_view_populate_popup_cb (WebKitWebView* web_view,
                 G_CALLBACK (midori_web_view_menu_download_activate_cb), view);
             gtk_widget_show (menuitem);
         }
+        #endif
         menuitem = gtk_image_menu_item_new_from_stock (STOCK_BOOKMARK_ADD, NULL);
         gtk_menu_shell_insert (GTK_MENU_SHELL (menu), menuitem, 5);
         g_signal_connect (menuitem, "activate",
@@ -1133,48 +1167,117 @@ webkit_web_view_create_web_view_cb (GtkWidget*      web_view,
 }
 
 static gboolean
-webkit_web_view_mime_type_decision_cb (GtkWidget*      web_view,
-                                       WebKitWebFrame* web_frame,
-                                       gpointer        request,
-                                       const gchar*    mime_type,
-                                       gpointer        decision,
-                                       MidoriView*     view)
+webkit_web_view_mime_type_decision_cb (GtkWidget*               web_view,
+                                       WebKitWebFrame*          web_frame,
+                                       WebKitNetworkRequest*    request,
+                                       const gchar*             mime_type,
+                                       WebKitWebPolicyDecision* decision,
+                                       MidoriView*              view)
 {
-    #if WEBKIT_CHECK_VERSION (1, 0, 0)
-    gchar* uri;
+    #if WEBKIT_CHECK_VERSION (1, 1, 3)
+    GtkWidget* dialog;
+    gchar* content_type;
+    gchar* description;
+    gchar* title;
+    GdkScreen* screen;
+    GtkIconTheme* icon_theme;
+    gint response;
     #endif
 
     if (web_frame != webkit_web_view_get_main_frame (WEBKIT_WEB_VIEW (web_view)))
         return FALSE;
 
-    katze_assign (view->mime_type, g_strdup (mime_type));
+    if (webkit_web_view_can_show_mime_type (WEBKIT_WEB_VIEW (web_view), mime_type))
+    {
+        katze_assign (view->mime_type, g_strdup (mime_type));
+        midori_view_update_icon (view, NULL);
+        g_object_notify (G_OBJECT (view), "mime-type");
+        return FALSE;
+    }
+
+    #if WEBKIT_CHECK_VERSION (1, 1, 3)
+    dialog = gtk_message_dialog_new (
+        NULL, 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
+        _("Open or download file"));
+    #if GLIB_CHECK_VERSION (2, 18, 0)
+    content_type = g_content_type_from_mime_type (mime_type);
+    #else
+    content_type = g_strdup (mime_type);
+    #endif
+    description = g_content_type_get_description (content_type);
+    g_free (content_type);
+    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+        _("File Type: %s ('%s')"), description, mime_type);
+    g_free (description);
+    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
+    /* i18n: A file open dialog title, ie. "Open http://fila.com/manual.tgz" */
+    title = g_strdup_printf (_("Open %s"),
+        webkit_network_request_get_uri (request));
+    gtk_window_set_title (GTK_WINDOW (dialog), title);
+    g_free (title);
+    screen = gtk_widget_get_screen (dialog);
+    if (screen)
+    {
+        icon_theme = gtk_icon_theme_get_for_screen (screen);
+        if (gtk_icon_theme_has_icon (icon_theme, STOCK_TRANSFER))
+            gtk_window_set_icon_name (GTK_WINDOW (dialog), STOCK_TRANSFER);
+        else
+            gtk_window_set_icon_name (GTK_WINDOW (dialog), GTK_STOCK_OPEN);
+    }
+    gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+        GTK_STOCK_SAVE, 1,
+        GTK_STOCK_CANCEL, 2,
+        GTK_STOCK_OPEN, 3,
+        NULL);
+    response = gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+    g_object_set_data (G_OBJECT (view), "open-download", (gpointer)0);
+    switch (response)
+    {
+        case 3:
+            g_object_set_data (G_OBJECT (view), "open-download", (gpointer)1);
+        case 1:
+            webkit_web_policy_decision_download (decision);
+            /* Apparently WebKit will continue loading which ends in an error.
+               It's unclear whether it's a bug or we are doing something wrong. */
+            webkit_web_view_stop_loading (WEBKIT_WEB_VIEW (view->web_view));
+            return TRUE;
+        case 2:
+        default:
+            /* Apparently WebKit will continue loading which ends in an error.
+               It's unclear whether it's a bug or we are doing something wrong. */
+            webkit_web_view_stop_loading (WEBKIT_WEB_VIEW (view->web_view));
+            return FALSE;
+    }
+    #else
+    katze_assign (view->mime_type, NULL);
     midori_view_update_icon (view, NULL);
     g_object_notify (G_OBJECT (view), "mime-type");
 
-    /* TODO: Display contents with a Viewable if WebKit can't do it */
-    /* TODO: Offer downloading file if it cannot be displayed at all */
-
-    #if WEBKIT_CHECK_VERSION (1, 1, 0)
-    if (webkit_web_view_can_show_mime_type (WEBKIT_WEB_VIEW (web_view), mime_type))
-    #else
-    if (g_str_has_prefix (mime_type, "image/") ||
-        g_strrstr (mime_type, "script") ||
-        g_str_has_prefix (mime_type, "text/") || g_strrstr (mime_type, "xml"))
-    #endif
-        return FALSE;
-
-    #if WEBKIT_CHECK_VERSION (1, 0, 0)
     uri = g_strdup_printf ("error:nodisplay %s",
         webkit_network_request_get_uri (request));
     midori_view_set_uri (view, uri);
     g_free (uri);
-    #else
-    midori_view_set_uri (view, "error:nodisplay ");
-    #endif
 
     return TRUE;
+    #endif
 }
 
+#if WEBKIT_CHECK_VERSION (1, 1, 3)
+static gboolean
+webkit_web_view_download_requested_cb (GtkWidget*      web_view,
+                                       WebKitDownload* download,
+                                       MidoriView*     view)
+{
+    gboolean handled;
+    g_object_set_data (G_OBJECT (download), "open-download",
+        g_object_get_data (G_OBJECT (view), "open-download"));
+    g_object_set_data (G_OBJECT (view), "open-download", (gpointer)0);
+    g_signal_emit (view, signals[DOWNLOAD_REQUESTED], 0, download, &handled);
+    return handled;
+}
+#endif
+
 static void
 webkit_web_view_console_message_cb (GtkWidget*   web_view,
                                     const gchar* message,
@@ -1557,12 +1660,9 @@ midori_view_construct_web_view (MidoriView* view)
     gpointer inspector;
 
     view->web_view = webkit_web_view_new ();
-    if (g_object_class_find_property (G_OBJECT_GET_CLASS (view->web_view), "session"))
-    #if HAVE_LIBSOUP
-        g_object_set (view->web_view, "session",
-                      katze_net_get_session (view->net), NULL);
-    #endif
 
+    /* Load something to avoid a bug where WebKit might not set a main frame */
+    webkit_web_view_open (WEBKIT_WEB_VIEW (view->web_view), "");
     web_frame = webkit_web_view_get_main_frame (WEBKIT_WEB_VIEW (view->web_view));
 
     g_object_connect (view->web_view,
@@ -1592,17 +1692,16 @@ midori_view_construct_web_view (MidoriView* view)
                       webkit_web_view_console_message_cb, view,
                       "signal::window-object-cleared",
                       webkit_web_view_window_object_cleared_cb, view,
-                      NULL);
-    if (g_signal_lookup ("create-web-view", WEBKIT_TYPE_WEB_VIEW))
-        g_object_connect (view->web_view,
                       "signal::create-web-view",
                       webkit_web_view_create_web_view_cb, view,
-                      NULL);
-    if (g_signal_lookup ("mime-type-policy-decision-requested", WEBKIT_TYPE_WEB_VIEW))
-        g_object_connect (view->web_view,
                       "signal::mime-type-policy-decision-requested",
                       webkit_web_view_mime_type_decision_cb, view,
+                      #if WEBKIT_CHECK_VERSION (1, 1, 3)
+                      "signal::download-requested",
+                      webkit_web_view_download_requested_cb, view,
+                      #endif
                       NULL);
+
     g_object_connect (web_frame,
                       "signal::load-done",
                       webkit_web_frame_load_done_cb, view,
@@ -1610,24 +1709,17 @@ midori_view_construct_web_view (MidoriView* view)
 
     if (view->settings)
     {
-        g_object_set (view->web_view, "settings", view->settings, NULL);
-        if (katze_object_has_property (view->web_view, "full-content-zoom"))
-            g_object_set (view->web_view, "full-content-zoom",
-                katze_object_get_boolean (view->settings,
-                                          "zoom-text-and-images"), NULL);
+        g_object_set (view->web_view, "settings", view->settings,
+            "full-content-zoom", katze_object_get_boolean (view->settings,
+                "zoom-text-and-images"), NULL);
     }
 
     gtk_widget_show (view->web_view);
     gtk_container_add (GTK_CONTAINER (view), view->web_view);
 
-    if (katze_object_has_property (view->web_view, "web-inspector"))
-    {
-        inspector = katze_object_get_object (view->web_view, "web-inspector");
-        g_object_connect (inspector,
-                          "signal::inspect-web-view",
-                          webkit_web_inspector_inspect_web_view_cb, view,
-                          NULL);
-    }
+    inspector = katze_object_get_object (view->web_view, "web-inspector");
+    g_object_connect (inspector, "signal::inspect-web-view",
+                      webkit_web_inspector_inspect_web_view_cb, view, NULL);
 }
 
 /**
@@ -1635,43 +1727,18 @@ midori_view_construct_web_view (MidoriView* view)
  * @view: a #MidoriView
  *
  * Opens the specified URI in the view.
- *
- * Pass an URI prefixed with "view-source:" in
- * order to create a source view.
  **/
 void
 midori_view_set_uri (MidoriView*  view,
                      const gchar* uri)
 {
-    GtkWidget* widget;
     gchar* data;
 
     g_return_if_fail (MIDORI_IS_VIEW (view));
 
     if (!uri) uri = "";
 
-    if (!view->web_view && view->uri
-        && g_str_has_prefix (view->uri, "view-source:"))
-    {
-        g_signal_emit (view, signals[NEW_TAB], 0, uri);
-    }
-    else if (!view->web_view && g_str_has_prefix (uri, "view-source:"))
-    {
-        katze_assign (view->uri, g_strdup (uri));
-        g_object_notify (G_OBJECT (view), "uri");
-        if (view->item)
-            katze_item_set_uri (view->item, uri);
-        data = g_strdup_printf ("%s - %s", _("Source"), &uri[12]);
-        g_object_set (view, "title", data, NULL);
-        g_free (data);
-        katze_object_assign (view->icon,
-            gtk_widget_render_icon (GTK_WIDGET (view),
-                GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU, NULL));
-        widget = midori_source_new (&uri[12]);
-        gtk_container_add (GTK_CONTAINER (view), widget);
-        gtk_widget_show (widget);
-    }
-    else
+    if (1)
     {
         if (!view->web_view)
             midori_view_construct_web_view (view);
@@ -1691,7 +1758,7 @@ midori_view_set_uri (MidoriView*  view,
                     "<body><h1>%s</h1>"
                     "<img src=\"file://" DATADIR "/midori/logo-shade.png\" "
                     "style=\"position: absolute; right: 15px; bottom: 15px;\">"
-                    "<p />The document %s of type %s cannot be displayed."
+                    "<p />The document %s of type '%s' cannot be displayed."
                     "</body></html>",
                     title, title, view->uri, view->mime_type);
                 g_free (title);
@@ -2248,13 +2315,11 @@ midori_view_get_proxy_item (MidoriView* view)
 gfloat
 midori_view_get_zoom_level (MidoriView* view)
 {
-    g_return_val_if_fail (MIDORI_IS_VIEW (view), 1.0);
+    g_return_val_if_fail (MIDORI_IS_VIEW (view), 1.0f);
 
-    #ifdef WEBKIT_CHECK_VERSION
     if (view->web_view != NULL)
         return webkit_web_view_get_zoom_level (WEBKIT_WEB_VIEW (view->web_view));
-    #endif
-    return 1.0;
+    return 1.0f;
 }
 
 /**
@@ -2270,10 +2335,9 @@ midori_view_set_zoom_level (MidoriView* view,
 {
     g_return_if_fail (MIDORI_IS_VIEW (view));
 
-    #ifdef WEBKIT_CHECK_VERSION
     webkit_web_view_set_zoom_level (
         WEBKIT_WEB_VIEW (view->web_view), zoom_level);
-    #endif
+    g_object_notify (G_OBJECT (view), "zoom-level");
 }
 
 gboolean
@@ -2281,11 +2345,7 @@ midori_view_can_zoom_in (MidoriView* view)
 {
     g_return_val_if_fail (MIDORI_IS_VIEW (view), FALSE);
 
-    #ifdef WEBKIT_CHECK_VERSION
     return view->web_view != NULL;
-    #else
-    return FALSE;
-    #endif
 }
 
 gboolean
@@ -2293,29 +2353,23 @@ midori_view_can_zoom_out (MidoriView* view)
 {
     g_return_val_if_fail (MIDORI_IS_VIEW (view), FALSE);
 
-    #ifdef WEBKIT_CHECK_VERSION
     return view->web_view != NULL;
-    #else
-    return FALSE;
-    #endif
 }
 
 gboolean
 midori_view_can_view_source (MidoriView* view)
 {
-    g_return_val_if_fail (MIDORI_IS_VIEW (view), FALSE);
-
     const gchar* uri = view->uri;
 
+    g_return_val_if_fail (MIDORI_IS_VIEW (view), FALSE);
+
     /* FIXME: Consider other types that are also text */
     if (!g_str_has_prefix (view->mime_type, "text/")
         && !g_strrstr (view->mime_type, "xml"))
         return FALSE;
 
-    #if HAVE_LIBSOUP
     if (g_str_has_prefix (uri, "http://") || g_str_has_prefix (uri, "https://"))
         return TRUE;
-    #endif
     if (g_str_has_prefix (uri, "file://"))
         return TRUE;
     return FALSE;
@@ -2349,7 +2403,10 @@ midori_view_reload (MidoriView* view,
 {
     g_return_if_fail (MIDORI_IS_VIEW (view));
 
-    webkit_web_view_reload (WEBKIT_WEB_VIEW (view->web_view));
+    if (from_cache)
+        webkit_web_view_reload (WEBKIT_WEB_VIEW (view->web_view));
+    else
+        webkit_web_view_reload_bypass_cache (WEBKIT_WEB_VIEW (view->web_view));
 }
 
 /**
@@ -2439,13 +2496,8 @@ midori_view_print (MidoriView* view)
 {
     g_return_if_fail (MIDORI_IS_VIEW (view));
 
-    #ifdef WEBKIT_CHECK_VERSION
     webkit_web_frame_print (webkit_web_view_get_main_frame (
         WEBKIT_WEB_VIEW (view->web_view)));
-    #else
-    webkit_web_view_execute_script (
-        WEBKIT_WEB_VIEW (view->web_view), "print();");
-    #endif
 }
 
 /**
@@ -2537,9 +2589,7 @@ midori_view_execute_script (MidoriView*  view,
 {
     WebKitWebFrame* web_frame;
     JSContextRef js_context;
-    #if HAVE_LIBSOUP
     gchar* script_decoded;
-    #endif
 
     g_return_val_if_fail (MIDORI_IS_VIEW (view), FALSE);
     g_return_val_if_fail (script != NULL, FALSE);
@@ -2547,7 +2597,6 @@ midori_view_execute_script (MidoriView*  view,
     /* FIXME Actually store exception. */
     web_frame = webkit_web_view_get_main_frame (WEBKIT_WEB_VIEW (view->web_view));
     js_context = webkit_web_frame_get_global_context (web_frame);
-    #if HAVE_LIBSOUP
     if ((script_decoded = soup_uri_decode (script)))
     {
         webkit_web_view_execute_script (WEBKIT_WEB_VIEW (view->web_view),
@@ -2555,7 +2604,6 @@ midori_view_execute_script (MidoriView*  view,
         g_free (script_decoded);
     }
     else
-    #endif
         webkit_web_view_execute_script (WEBKIT_WEB_VIEW (view->web_view), script);
     return TRUE;
 }
