@@ -36,6 +36,7 @@ struct _MidoriWebSettings
     gboolean show_navigationbar;
     gboolean show_bookmarkbar;
     gboolean show_panel;
+    gboolean show_transferbar;
     gboolean show_statusbar;
 
     MidoriToolbarStyle toolbar_style;
@@ -103,6 +104,7 @@ enum
     PROP_SHOW_NAVIGATIONBAR,
     PROP_SHOW_BOOKMARKBAR,
     PROP_SHOW_PANEL,
+    PROP_SHOW_TRANSFERBAR,
     PROP_SHOW_STATUSBAR,
 
     PROP_TOOLBAR_STYLE,
@@ -291,6 +293,18 @@ midori_web_settings_get_property (GObject*    object,
                                   GValue*     value,
                                   GParamSpec* pspec);
 
+static const gchar*
+midori_get_download_dir (void)
+{
+    const gchar* dir = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
+    if (dir)
+    {
+        g_mkdir_with_parents (dir, 0700);
+        return dir;
+    }
+    return g_get_home_dir ();
+}
+
 static void
 midori_web_settings_class_init (MidoriWebSettingsClass* class)
 {
@@ -413,6 +427,22 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      FALSE,
                                      flags));
 
+    /**
+     * MidoriWebSettings:show-transferbar:
+     *
+     * Whether to show the transferbar.
+     *
+     * Since: 0.1.5
+     */
+    g_object_class_install_property (gobject_class,
+                                     PROP_SHOW_TRANSFERBAR,
+                                     g_param_spec_boolean (
+                                     "show-transferbar",
+                                     _("Show Transferbar"),
+                                     _("Whether to show the transferbar"),
+                                     TRUE,
+                                     flags));
+
     g_object_class_install_property (gobject_class,
                                      PROP_SHOW_STATUSBAR,
                                      g_param_spec_boolean (
@@ -525,8 +555,12 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      "download-folder",
                                      _("Download Folder"),
                                      _("The folder downloaded files are saved to"),
-                                     g_get_home_dir (),
-                                     G_PARAM_READABLE));
+                                     midori_get_download_dir (),
+    #if WEBKIT_CHECK_VERSION (1, 1, 3)
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+    #else
+                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+    #endif
 
     g_object_class_install_property (gobject_class,
                                      PROP_DOWNLOAD_MANAGER,
@@ -584,7 +618,6 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      TRUE,
                                      flags));
 
-    g_type_class_ref (WEBKIT_TYPE_WEB_VIEW);
     g_object_class_install_property (gobject_class,
                                      PROP_OPEN_NEW_PAGES_IN,
                                      g_param_spec_enum (
@@ -593,8 +626,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      _("Where to open new pages"),
                                      MIDORI_TYPE_NEW_PAGE,
                                      MIDORI_NEW_PAGE_TAB,
-    (g_signal_lookup ("create-web-view", WEBKIT_TYPE_WEB_VIEW)
-        ? G_PARAM_READWRITE : G_PARAM_READABLE) | G_PARAM_STATIC_STRINGS));
+                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     g_object_class_install_property (gobject_class,
                                      PROP_OPEN_EXTERNAL_PAGES_IN,
@@ -647,58 +679,21 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 
-    if (!g_object_class_find_property (gobject_class, "enforce-96-dpi"))
     /**
-    * MidoriWebSettings:enforce-96-dpi:
-    *
-    * Whether to enforce a resolution of 96 DPI.
-    *
-    * Since: 0.1.2
-    */
-    g_object_class_install_property (gobject_class,
-                                     PROP_ENFORCE_96_DPI,
-                                     g_param_spec_boolean (
-                                     "enforce-96-dpi",
-                                     "Enforce 96 DPI",
-                                     "Whether to enforce a resolution of 96 DPI",
-                                     FALSE,
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-
-    if (!g_object_class_find_property (gobject_class, "enable-developer-extras"))
-    /**
-    * MidoriWebSettings:enable-developer-extras:
-    *
-    * Whether to enable extra developer tools.
-    *
-    * Since: 0.1.2
-    */
-    g_object_class_install_property (gobject_class,
-                                     PROP_ENABLE_DEVELOPER_EXTRAS,
-                                     g_param_spec_boolean (
-                                     "enable-developer-extras",
-                                     "Enable Developer Extras",
-                                     "Whether to enable extra developer tools",
-                                     FALSE,
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-
-    if (!g_object_class_find_property (gobject_class, "zoom-text-and-images"))
-    /**
-    * MidoriWebSettings:zoom-text-and-images:
-    *
-    * Whether to zoom text and images.
-    *
-    * Since: 0.1.3
-    */
-    g_object_class_install_property (gobject_class,
-                                     PROP_ZOOM_TEXT_AND_IMAGES,
-                                     g_param_spec_boolean (
-                                     "zoom-text-and-images",
-                                     _("Zoom Text and Images"),
-                                     _("Whether to zoom text and images"),
-                                     FALSE,
-    (g_object_class_find_property (g_type_class_ref (WEBKIT_TYPE_WEB_VIEW),
-        "full-content-zoom") ? G_PARAM_READWRITE : G_PARAM_READABLE)
-        | G_PARAM_STATIC_STRINGS));
+     * MidoriWebSettings:zoom-text-and-images:
+     *
+     * Whether to zoom text and images.
+     *
+     * Since: 0.1.3
+     */
+     g_object_class_install_property (gobject_class,
+                                      PROP_ZOOM_TEXT_AND_IMAGES,
+                                      g_param_spec_boolean (
+                                      "zoom-text-and-images",
+                                      _("Zoom Text and Images"),
+                                      _("Whether to zoom text and images"),
+                                      FALSE,
+                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
     /**
     * MidoriWebSettings:find-while-typing:
@@ -713,7 +708,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      "find-while-typing",
                                      _("Find inline while typing"),
                                      _("Whether to automatically find inline while typing"),
-                                     TRUE,
+                                     FALSE,
                                      flags));
 
     g_object_class_install_property (gobject_class,
@@ -724,11 +719,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      _("What type of cookies to accept"),
                                      MIDORI_TYPE_ACCEPT_COOKIES,
                                      MIDORI_ACCEPT_COOKIES_ALL,
-                                     #if HAVE_LIBSOUP
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-                                     #else
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-                                     #endif
 
     g_object_class_install_property (gobject_class,
                                      PROP_ORIGINAL_COOKIES_ONLY,
@@ -795,11 +786,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      _("Proxy Server"),
                                      _("The proxy server used for HTTP connections"),
                                      NULL,
-                                     #if HAVE_LIBSOUP
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-                                     #else
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-                                     #endif
 
     /**
     * MidoriWebSettings:auto-detect-proxy:
@@ -815,11 +802,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      _("Detect proxy server automatically"),
         _("Whether to detect the proxy server automatically from the environment"),
                                      TRUE,
-                                     #if HAVE_LIBSOUP
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-                                     #else
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-                                     #endif
 
     /**
     * MidoriWebSettings:identify-as:
@@ -837,11 +820,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      _("What to identify as to web pages"),
                                      MIDORI_TYPE_IDENTITY,
                                      MIDORI_IDENT_MIDORI,
-                                     #if HAVE_LIBSOUP
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-                                     #else
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-                                     #endif
 
     /**
     * MidoriWebSettings:ident-string:
@@ -857,11 +836,7 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      _("Identification string"),
                                      _("The application identification string"),
                                      NULL,
-                                     #if HAVE_LIBSOUP
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-                                     #else
-                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
-                                     #endif
 
     g_object_class_install_property (gobject_class,
                                      PROP_CACHE_SIZE,
@@ -903,6 +878,7 @@ notify_default_encoding_cb (GObject*    object,
 static void
 midori_web_settings_init (MidoriWebSettings* web_settings)
 {
+    web_settings->download_folder = g_strdup (midori_get_download_dir ());
     web_settings->http_proxy = NULL;
     web_settings->open_popups_in_tabs = TRUE;
     web_settings->remember_last_form_inputs = TRUE;
@@ -1029,6 +1005,9 @@ midori_web_settings_set_property (GObject*      object,
     case PROP_SHOW_PANEL:
         web_settings->show_panel = g_value_get_boolean (value);
         break;
+    case PROP_SHOW_TRANSFERBAR:
+        web_settings->show_transferbar = g_value_get_boolean (value);
+        break;
     case PROP_SHOW_STATUSBAR:
         web_settings->show_statusbar = g_value_get_boolean (value);
         break;
@@ -1219,6 +1198,9 @@ midori_web_settings_get_property (GObject*    object,
     case PROP_SHOW_PANEL:
         g_value_set_boolean (value, web_settings->show_panel);
         break;
+    case PROP_SHOW_TRANSFERBAR:
+        g_value_set_boolean (value, web_settings->show_transferbar);
+        break;
     case PROP_SHOW_STATUSBAR:
         g_value_set_boolean (value, web_settings->show_statusbar);
         break;
