@@ -34,6 +34,20 @@ G_BEGIN_DECLS
 typedef struct _MidoriWebSettings                MidoriWebSettings;
 typedef struct _MidoriWebSettingsClass           MidoriWebSettingsClass;
 
+typedef enum
+{
+    MIDORI_WINDOW_NORMAL,
+    MIDORI_WINDOW_MINIMIZED,
+    MIDORI_WINDOW_MAXIMIZED,
+    MIDORI_WINDOW_FULLSCREEN,
+} MidoriWindowState;
+
+GType
+midori_window_state_get_type (void) G_GNUC_CONST;
+
+#define MIDORI_TYPE_WINDOW_STATE \
+    (midori_window_state_get_type ())
+
 typedef enum
 {
     MIDORI_STARTUP_BLANK_PAGE,
@@ -104,10 +118,20 @@ midori_accept_cookies_get_type (void) G_GNUC_CONST;
 #define MIDORI_TYPE_ACCEPT_COOKIES \
     (midori_accept_cookies_get_type ())
 
-struct _MidoriWebSettingsClass
+typedef enum
 {
-    WebKitWebSettingsClass parent_class;
-};
+    MIDORI_IDENT_MIDORI,
+    MIDORI_IDENT_SAFARI,
+    MIDORI_IDENT_FIREFOX,
+    MIDORI_IDENT_EXPLORER,
+    MIDORI_IDENT_CUSTOM
+} MidoriIdentity;
+
+GType
+midori_identity_get_type (void) G_GNUC_CONST;
+
+#define MIDORI_TYPE_IDENTITY \
+    (midori_identity_get_type ())
 
 GType
 midori_web_settings_get_type               (void);
