@@ -17,8 +17,6 @@
 #include "midori-bookmarks.h"
 #include "sokoke.h"
 
-#if GLIB_CHECK_VERSION(2, 16, 0)
-
 #define pspec_is_writable(pspec) (pspec->flags & G_PARAM_WRITABLE \
     && !(pspec->flags & (G_PARAM_CONSTRUCT | G_PARAM_CONSTRUCT_ONLY)))
 
@@ -174,8 +172,6 @@ main (int    argc,
         (gconstpointer)MIDORI_TYPE_PREFERENCES, properties_type_test);
     g_test_add_data_func ("/properties/search-action",
         (gconstpointer)MIDORI_TYPE_SEARCH_ACTION, properties_type_test);
-    g_test_add_data_func ("/properties/source",
-        (gconstpointer)MIDORI_TYPE_SOURCE, properties_type_test);
     g_test_add_data_func ("/properties/view",
         (gconstpointer)MIDORI_TYPE_VIEW, properties_type_test);
     g_test_add_data_func ("/properties/viewable",
@@ -185,5 +181,3 @@ main (int    argc,
 
     return g_test_run ();
 }
-
-#endif
